@@ -3,7 +3,7 @@ use crate::nixpacks::{
     app::App,
     environment::Environment,
     nix::Pkg,
-    phase::{SetupPhase, StartPhase},
+    phase::{BuildPhase, SetupPhase, StartPhase},
 };
 use anyhow::Result;
 use regex::Regex;
@@ -17,14 +17,36 @@ impl Provider for DenoProvider {
 
     fn detect(&self, app: &App, _env: &Environment) -> Result<bool> {
         let re = Regex::new(r##"(?m)^import .+ from "https://deno.land/[^"]+\.ts";?$"##).unwrap();
-        app.find_match(&re, "**/*.ts")
+        Ok(app.includes_file("deno.json")
+            || app.includes_file("deno.jsonc")
+            || app.find_match(&re, "**/*.ts")?)
     }
 
     fn setup(&self, _app: &App, _env: &Environment) -> Result<Option<SetupPhase>> {
         Ok(Some(SetupPhase::new(vec![Pkg::new("deno")])))
     }
 
+    fn build(&self, app: &App, _env: &Environment) -> Result<Option<BuildPhase>> {
+        match DenoProvider::get_start_file(app)? {
+            Some(start_file) => Ok(Some(BuildPhase::new(format!("deno cache {}", start_file)))),
+            None => Ok(None),
+        }
+    }
+
     fn start(&self, app: &App, _env: &Environment) -> Result<Option<StartPhase>> {
+        match DenoProvider::get_start_file(app)? {
+            Some(start_file) => Ok(Some(StartPhase::new(format!(
+                "deno run --allow-all {}",
+                start_file
+            )))),
+            None => Ok(None),
+        }
+    }
+}
+
+impl DenoProvider {
+    // Find the first index.ts or index.js file to run
+    fn get_start_file(app: &App) -> Result<Option<String>> {
         // Find the first index.ts or index.js file to run
         let matches = app.find_files("**/index.[tj]s")?;
         let path_to_index = match matches.first() {
@@ -33,9 +55,6 @@ impl Provider for DenoProvider {
         };
 
         let relative_path_to_index = app.strip_source_path(&path_to_index)?;
-        return Ok(Some(StartPhase::new(format!(
-            "deno run --allow-all {}",
-            relative_path_to_index
-        ))));
+        Ok(Some(relative_path_to_index))
     }
 }
