@@ -34,22 +34,15 @@ impl Provider for NpmProvider {
         Ok(app.includes_file("package.json"))
     }
 
-    fn setup(&self, app: &App, _env: &Environment) -> Result<Option<SetupPhase>> {
+    fn setup(&self, app: &App, env: &Environment) -> Result<Option<SetupPhase>> {
         let package_json: PackageJson = app.read_json("package.json")?;
-        let node_pkg = NpmProvider::get_nix_node_pkg(&package_json)?;
+        let node_pkg = NpmProvider::get_nix_node_pkg(&package_json, env)?;
 
         Ok(Some(SetupPhase::new(vec![node_pkg])))
     }
 
-    fn install(&self, app: &App, _env: &Environment) -> Result<Option<InstallPhase>> {
-        let mut install_phase = InstallPhase::new("npm install".to_string());
-
-        // Installing node modules only depends on package.json and lock file
-        install_phase.add_file_dependency("package.json".to_string());
-        if app.includes_file("package-lock.json") {
-            install_phase.add_file_dependency("package-lock.json".to_string());
-        }
-
+    fn install(&self, _app: &App, _env: &Environment) -> Result<Option<InstallPhase>> {
+        let install_phase = InstallPhase::new("npm ci".to_string());
         Ok(Some(install_phase))
     }
 
@@ -117,12 +110,16 @@ impl NpmProvider {
     }
 
     /// Parses the package.json engines field and returns a Nix package if available
-    pub fn get_nix_node_pkg(package_json: &PackageJson) -> Result<Pkg> {
-        let node_version = package_json
+    pub fn get_nix_node_pkg(package_json: &PackageJson, environment: &Environment) -> Result<Pkg> {
+        let env_node_version = environment.get_config_variable("NODE_VERSION");
+
+        let pkg_node_version = package_json
             .engines
             .as_ref()
             .and_then(|engines| engines.get("node"));
 
+        let node_version = pkg_node_version.or(env_node_version);
+
         let node_version = match node_version {
             Some(node_version) => node_version,
             None => return Ok(Pkg::new(DEFAULT_NODE_PKG_NAME)),
@@ -134,7 +131,7 @@ impl NpmProvider {
         }
 
         // Parse `12` or `12.x` into nodejs-12_x
-        let re = Regex::new(r"^(\d+)\.?x?$").unwrap();
+        let re = Regex::new(r"^(\d+)\.?[x|X]?$").unwrap();
         if let Some(node_pkg) = parse_regex_into_pkg(&re, node_version)? {
             return Ok(Pkg::new(node_pkg.as_str()));
         }
@@ -180,13 +177,16 @@ mod test {
     #[test]
     fn test_no_engines() -> Result<()> {
         assert_eq!(
-            NpmProvider::get_nix_node_pkg(&PackageJson {
-                name: String::default(),
-                main: None,
-                scripts: None,
-                workspaces: None,
-                engines: None
-            })?,
+            NpmProvider::get_nix_node_pkg(
+                &PackageJson {
+                    name: String::default(),
+                    main: None,
+                    scripts: None,
+                    workspaces: None,
+                    engines: None
+                },
+                &Environment::default()
+            )?,
             Pkg::new(DEFAULT_NODE_PKG_NAME)
         );
 
@@ -196,13 +196,16 @@ mod test {
     #[test]
     fn test_star_engine() -> Result<()> {
         assert_eq!(
-            NpmProvider::get_nix_node_pkg(&PackageJson {
-                name: String::default(),
-                main: None,
-                scripts: None,
-                workspaces: None,
-                engines: engines_node("*")
-            })?,
+            NpmProvider::get_nix_node_pkg(
+                &PackageJson {
+                    name: String::default(),
+                    main: None,
+                    scripts: None,
+                    workspaces: None,
+                    engines: engines_node("*")
+                },
+                &Environment::default()
+            )?,
             Pkg::new(DEFAULT_NODE_PKG_NAME)
         );
 
@@ -212,13 +215,16 @@ mod test {
     #[test]
     fn test_simple_engine() -> Result<()> {
         assert_eq!(
-            NpmProvider::get_nix_node_pkg(&PackageJson {
-                name: String::default(),
-                main: None,
-                scripts: None,
-                workspaces: None,
-                engines: engines_node("14"),
-            })?,
+            NpmProvider::get_nix_node_pkg(
+                &PackageJson {
+                    name: String::default(),
+                    main: None,
+                    scripts: None,
+                    workspaces: None,
+                    engines: engines_node("14"),
+                },
+                &Environment::default()
+            )?,
             Pkg::new("nodejs-14_x")
         );
 
@@ -228,29 +234,71 @@ mod test {
     #[test]
     fn test_simple_engine_x() -> Result<()> {
         assert_eq!(
-            NpmProvider::get_nix_node_pkg(&PackageJson {
-                name: String::default(),
-                main: None,
-                scripts: None,
-                workspaces: None,
-                engines: engines_node("12.x"),
-            })?,
+            NpmProvider::get_nix_node_pkg(
+                &PackageJson {
+                    name: String::default(),
+                    main: None,
+                    scripts: None,
+                    workspaces: None,
+                    engines: engines_node("12.x"),
+                },
+                &Environment::default()
+            )?,
             Pkg::new("nodejs-12_x")
         );
 
+        assert_eq!(
+            NpmProvider::get_nix_node_pkg(
+                &PackageJson {
+                    name: String::default(),
+                    main: None,
+                    scripts: None,
+                    workspaces: None,
+                    engines: engines_node("14.X"),
+                },
+                &Environment::default()
+            )?,
+            Pkg::new("nodejs-14_x")
+        );
+
         Ok(())
     }
 
     #[test]
     fn test_engine_range() -> Result<()> {
         assert_eq!(
-            NpmProvider::get_nix_node_pkg(&PackageJson {
-                name: String::default(),
-                main: None,
-                scripts: None,
-                workspaces: None,
-                engines: engines_node(">=14.10.3 <16"),
-            })?,
+            NpmProvider::get_nix_node_pkg(
+                &PackageJson {
+                    name: String::default(),
+                    main: None,
+                    scripts: None,
+                    workspaces: None,
+                    engines: engines_node(">=14.10.3 <16"),
+                },
+                &Environment::default()
+            )?,
+            Pkg::new("nodejs-14_x")
+        );
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_version_from_environment_variable() -> Result<()> {
+        assert_eq!(
+            NpmProvider::get_nix_node_pkg(
+                &PackageJson {
+                    name: String::default(),
+                    main: None,
+                    scripts: None,
+                    workspaces: None,
+                    engines: None,
+                },
+                &Environment::new(HashMap::from([(
+                    "NIXPACKS_NODE_VERSION".to_string(),
+                    "14".to_string()
+                )]))
+            )?,
             Pkg::new("nodejs-14_x")
         );
 
@@ -259,13 +307,16 @@ mod test {
 
     #[test]
     fn test_engine_invalid_version() -> Result<()> {
-        assert!(NpmProvider::get_nix_node_pkg(&PackageJson {
-            name: String::default(),
-            main: None,
-            scripts: None,
-            workspaces: None,
-            engines: engines_node("15"),
-        })
+        assert!(NpmProvider::get_nix_node_pkg(
+            &PackageJson {
+                name: String::default(),
+                main: None,
+                scripts: None,
+                workspaces: None,
+                engines: engines_node("15"),
+            },
+            &Environment::default()
+        )
         .is_err());
 
         Ok(())
